@@ -336,7 +336,7 @@ int  checkPhysValN(char * name, char * key, physValRec **pLists)
     for(i=i0;i<ln-1;i++) if(tmp[i]==tmp[i+1]) break;
     if(i==ln-1)
     { 
-      if(*key=='P' && strchr(tmp+1,tmp[0]))continue;
+      if(*key!='P' || strchr(tmp+1,tmp[0])==NULL)
       { physValRec * cc= *pLists;
         for(;cc;cc=cc->next) if(strcmp(tmp,cc->pstr)==0)break; 
         if(!cc)
