@@ -399,8 +399,8 @@ int mkmom(double*x,double*tfact,double*xp1,double*xp2,REAL*pvect)
 	  *tfact=0;
 	  return 0;
 	}  
-	decay_1(nvpole, hsum, &hdif,&memDecay,pvect);
-
+        decay_1(nvpole, hsum, &hdif,&memDecay,pvect);
+        
 	cosmin = -1;
 	cosmax = 1;
 	nsing = 0;
@@ -418,7 +418,6 @@ int mkmom(double*x,double*tfact,double*xp1,double*xp2,REAL*pvect)
 	fct_1__ = sph_inf[i][ns___].sph_we / fct;
 	parfi = (xfi * 2 - 1) * M_PI;
 	decay_3(nvposy, parcos, parfi, nvout[i][0], nvout[i][1],&memDecay,pvect);
-
 	
 	i__2 = nsph[i];
 	for (ns = 0; ns < i__2; ++ns)  if (ns != ns___)
@@ -531,7 +530,10 @@ int imkmom(double P1, double P2)
     if (nin_int == 2) 
     {  REAL m1=sf_num[0]?sf_mass[0]:pm[0];
        REAL m2=sf_num[1]?sf_mass[1]:pm[1];
-       
+
+       if(sf_num[0] && m1<sf_mass[0]) m1=sf_mass[0];
+       if(sf_num[1] && m2<sf_mass[1]) m1=sf_mass[1];
+              
        incomkin(m1, m2, P1, P2,  &sqrt_S, &pcm, &rapidity);
 
        ssmin=pm[0]+pm[1]; 
@@ -656,7 +658,7 @@ int imkmom(double P1, double P2)
 	if (nsph[i] == 0) 
 	{
 	   nsph[i] = 1;
-           sph_inf[i][0].lvpole[0] = (i == 0 && nin_int == 1 )?  nvposx:1;
+           sph_inf[i][0].lvpole[0] = (/*i == 0 &&*/ nin_int == 1 )?  nvposx:1;
 	   sph_inf[i][0].lvpole[1] = 0;
 	   sph_inf[i][0].itypep = 1;
 	} else 
