@@ -205,8 +205,22 @@ static int  testin(int l,decayDiagram restmp)
 	 }
       }
    }
-   if(l==ndecay) {for(j=0;liminsp[j].who;j++) if(copyins[j]<-1) return 0;}
-   
+
+   if(l==ndecay) 
+   { int nVV=0,pdg;
+     for(j=0;liminsp[j].who;j++) if(copyins[j]<-1) return 0;
+     for (i = 1; i <= 2 * (l - 1); i++)
+     { np = restmp[i-1];
+       if (np < 0)
+       {  np = -np-1;
+          pdg=prtclbase[np].N;
+          if(pdg==23 || abs(pdg)==24)nVV++;               
+       } 
+     }
+     
+     if(nVV > ZWmax || nVV < ZWmin) return 0; 
+   }
+
    return (nneed <= 0);
 }
 
