@@ -29,7 +29,6 @@
 /* ======================================================== */
 typedef char prtclsarray[MAXINOUT][P_NAME_SIZE];
 
-int noPict=0;
 int noCChain=0;
 int tWidths=0;
 static int sumDiag=0;
@@ -401,7 +400,7 @@ static void  onediagram(deninforec* dendescript)
    pos_c= ftell(outFile); writeF("%80s\n","");
   
    writeF("if(!DP){C%d(C); return 0;} \n",diagrcount);
-   
+   if(nin==2) writeF("  REAL N_p1p2_=1/DP[0];\n");
    fortwriter("N",totnum);
    fortwriter("D",totdenum);
    fortwriter("R",rnum);
@@ -441,7 +440,7 @@ static int  alldiagrams(FILE * fd,  int nsub)
    writeF("REAL N,D,R; COMPLEX Prop;\n");
    pos_c1= ftell(outFile); writeF("%70s\n","");   
    writeF("if(!momenta){ C%d(C); return 0;}\n",nsub);
-
+   if(nin==2) writeF("  REAL N_p1p2_=1/DP[0];\n");
    while(FREAD1(dendescript,fd) == 1)
    {
       fseek(catalog,dendescript.cr_pos,SEEK_SET);
@@ -1118,7 +1117,7 @@ static int c_prog_int(void)
    fseek(catalog,0,SEEK_SET);
    { catrec  cr;
      ndiagrtot =0;
-     while(FREAD1(cr,catalog)) if(cr.status=1) ndiagrtot++; 
+     while(FREAD1(cr,catalog)) if(cr.status==1) ndiagrtot++; 
    }
    writesubroutineinit();
    
