@@ -238,8 +238,12 @@ static int  readvars(int  check)
       trim(name); trim(numtxt);
       if(name[0]=='%') continue;
       for(i=1;i<=nv0;i++) if(strcmp(name,resName[i])==0) break;
-      if(i<=nv0) continue;
-        
+      if(i<=nv0){ if(check)
+                  {  char txt[50];
+                     sprintf(txt,"Variable %s ignored",resName[i]); 
+                     messanykey(10,10,txt);   
+                  }  continue;
+                }
       if (check && (!isVarName(name)) )
       {  errorMessage("Name","incorrect or reserved name '%s'",name);
          goto errExi1;
@@ -288,9 +292,14 @@ static int  readvars(int  check)
             }  
             continue;
          }
-         for(i=1;i<nv0;i++) if( strcmp(name,resName[i])==0) break;
-         if(i<nv0)  continue;
-      }
+         for(i=1;i<=nv0;i++) if( strcmp(name,resName[i])==0) break;
+         if(i<=nv0){   if(check)
+                       { char txt[50];
+                         sprintf(txt,"Constraint %s ignored",resName[i]); 
+                         messanykey(10,10,txt);   
+                       }  continue;
+                   }
+      }               
       if (! isVarName(name))
       {  errorMessage("Name","incorrect or reserved name '%s'",name);
 	 goto errExi1;
@@ -546,6 +555,7 @@ static int  readparticles(int  check, int ugForce )
             return 0;
          }
       }
+
       prtclbase[nparticles-1].spin=itmp;
       
       if( 1!=sscanf(numtxt,"%ld",&prtclbase[nparticles-1].N)) prtclbase[nparticles-1].N=0;
@@ -1134,11 +1144,12 @@ exi:;
 static int find3charge(void)
 {
   int i,cont;
+  int photon=-1;
   for(i=0;i<nparticles;i++) if(prtclbase[i].nHerm) prtclbase[i].q3=0;
 
   for(cont=1;cont;)
   { cont=0;  
-    for(i=0;i<nparticles;i++) if(/*prtclbase[i].hlp!='*' && */  ghostmother(i+1)==i+1 && prtclbase[i].q3==unknownQ3)
+    for(i=0;i<nparticles;i++) if(ghostmother(i+1)==i+1 && prtclbase[i].q3==unknownQ3)
     { decaylink dec=prtclbase[i].top;
       for(;dec;dec=dec->next)
       { int j,ch,br ;
@@ -1148,9 +1159,35 @@ static int find3charge(void)
           { prtclbase[i].q3=ch; cont=1;
             if(i+1 !=prtclbase[i].anti) prtclbase[prtclbase[i].anti-1].q3=-prtclbase[i].q3;
             break;
-          }          
+          } 
       }
     }
+    
+    if(cont==0 &&  photon!=-2)
+    { 
+      if(photon==-1) for(photon=0;photon<nparticles;photon++)
+      {
+        if( ghostmother(photon+1)==photon+1 && prtclbase[photon].N==22) break;
+           
+      }
+      if(photon==nparticles) photon=-2;      	
+      if(photon>=0) for(i=0;i<nparticles;i++) if(ghostmother(i+1)==i+1 && prtclbase[i].q3==unknownQ3)
+      {  decaylink dec=prtclbase[i].top;
+         int i_=prtclbase[i].anti-1;
+        
+         for(;dec;dec=dec->next)
+         {  
+            if(dec->part[2]==0 && ( (dec->part[0]-1==photon && dec->part[1]-1==i)
+                                 || (dec->part[1]-1==photon && dec->part[0]-1==i))) break;                   
+         }
+         if(dec==NULL)
+         {  prtclbase[i].q3=0;
+            prtclbase[i_].q3=0;
+            cont=1;
+         }             
+      }
+      photon=-2;
+    }
   }
     
   for(i=0;i<nparticles;i++) if(prtclbase[i].hlp!='*' && prtclbase[i].q3==unknownQ3)
@@ -1214,7 +1251,6 @@ static void  readEXTLIB(void)
 }    
 
 
-
 int  loadModel(int check,int ugForce)
 { 
   errorText[0]=0;
@@ -1233,6 +1269,7 @@ int  loadModel(int check,int ugForce)
   if(check && ! checkQ3()) {if(blind)  sortie(125); else return 0;}
 //  readEXTLIB();
   ldModelStatus=1+2+4*ugForce;
+  
   return 1;
 }
 
