@@ -170,7 +170,7 @@ static void*  rd_rcode(char* s)
 
 char* parseVertex(int v, int forReduce)
 { 
-  int j;
+  int i,j;
   int sgn=1;
   char *pstr, *pstr2;
 
@@ -190,14 +190,19 @@ char* parseVertex(int v, int forReduce)
      sortie(60);
   }
   
-  if (vcs.valence[v] == 3 &&
-          prtclbase1[vcs.vertlist[v][0].partcl].cdim == 8 &&
-          prtclbase1[vcs.vertlist[v][1].partcl].cdim == 8 &&
-          prtclbase1[vcs.vertlist[v][2].partcl].cdim == 8)
+  int nc=0;
+  int cdi[MAXVALENCE],si[MAXVALENCE],rsubst[MAXVALENCE];
+  for(i=0;i<vcs.valence[v];i++) rsubst[vertexes[v].subst[i]-1]=i+1;
+  for(i=0;i<vcs.valence[v];i++)if(prtclbase1[vcs.vertlist[v][i].partcl].cdim!=1)
+  {  si[nc]=rsubst[i];
+     cdi[nc++]=prtclbase1[vcs.vertlist[v][i].partcl].cdim;
+  }
+
+  if(nc==3 && cdi[0]==cdi[1] && cdi[0]==cdi[2] && (abs(cdi[0])==3 || cdi[0]==8))
   {
-         if (vertexes[v].subst[0] > vertexes[v].subst[1]) sgn = -sgn;
-         if (vertexes[v].subst[1] > vertexes[v].subst[2]) sgn = -sgn;
-         if (vertexes[v].subst[0] > vertexes[v].subst[2]) sgn = -sgn;
+         if (si[0] > si[1]) sgn*= -1;
+         if (si[1] > si[2]) sgn*= -1;
+         if (si[0] > si[2]) sgn*= -1;
   }
    
   if(sgn==1) 
@@ -283,7 +288,6 @@ char * spin3_2_propagator(int v,int l,int forReduce)
   sprintf(txt, "-3*(%sG(%sp%d)+%s)"
                "*(%s^2*m%d.m%d - p%d.m%d*p%d.m%d)"
                "-(G(%sm%d)*%s +(%sp%d.m%d))"
-
                "*(%sG(%sp%d)-%s)"
                "*(G(%sm%d)*%s+(%sp%d.m%d))"
 
