@@ -72,7 +72,7 @@ static void  savepoly(poly p)
 }
 
 
-void  saveanaliticresult(poly rnum,poly factn,poly factd, vcsect vcs, int nFile)
+void  saveanaliticresult(poly rnum,poly factn,poly factd, vcsect vcs, int ndiagr_abs,  int nFile)
 {catrec      cr;
  int        i;
  int m;
@@ -81,7 +81,15 @@ void  saveanaliticresult(poly rnum,poly factn,poly factd, vcsect vcs, int nFile)
 
    cr.nsub_ = nsub;
    cr.ndiagr_ = ndiagr;
-       
+   cr.ndiagr_abs=ndiagr_abs;    
+   if(!rnum) 
+   { cr.status=2;
+     cr.factpos=cr.nFile=cr.rnumpos=cr.denompos=-1;
+     FWRITE1(cr,catalog);
+     diskerror = NULL;
+     return;
+   }
+   cr.status=1;  
    cr.factpos = ftell(archiv);
    cr.nFile=nFile;
    vardef++;
